@@ -18,20 +18,24 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
+*> \date November 2017
 *
 *> \ingroup auxOTHERauxiliary
 *
-*  =====================================================================      PROGRAM LAPACK_VERSION
+*  =====================================================================
+      PROGRAM LAPACK_VERSION
 *
-*  -- LAPACK auxiliary routine (version 3.7.0) --
+*  -- LAPACK auxiliary routine (version 3.8.0) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
+*     November 2017
 *
       INTEGER MAJOR, MINOR, PATCH
+*     ..
+*     .. External Subroutines ..
+      EXTERNAL ILAVER
 *
-      CALL ILAVER ( MAJOR,MINOR, PATCH )
+      CALL ILAVER ( MAJOR, MINOR, PATCH )
       WRITE(*,*) "LAPACK ",MAJOR,".",MINOR,".",PATCH
 *
       END
