@@ -47,12 +47,14 @@ lapack_int LAPACKE_csytri_3( int matrix_layout, char uplo, lapack_int n,
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    if( LAPACKE_csy_nancheck( matrix_layout, uplo, n, a, lda ) ) {
-        return -4;
-    }
-    if( LAPACKE_c_nancheck( n-1, e + e_start, 1 ) ) {
-        return -6;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        if( LAPACKE_csy_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+            return -4;
+        }
+        if( LAPACKE_c_nancheck( n-1, e + e_start, 1 ) ) {
+            return -6;
+        }
     }
 #endif
     /* Query optimal working array(s) size */
