@@ -2,19 +2,19 @@
 *
 *  =========== DOCUMENTATION ===========
 *
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
 *
 *  Definition:
 *  ===========
 *
 *       SUBROUTINE SERRED( PATH, NUNIT )
-* 
+*
 *       .. Scalar Arguments ..
 *       CHARACTER*3        PATH
 *       INTEGER            NUNIT
 *       ..
-*  
+*
 *
 *> \par Purpose:
 *  =============
@@ -36,6 +36,8 @@
 *>       SGEJSV   compute SVD of an M-by-N matrix A where M >= N
 *>       SGESVDX  compute SVD of an M-by-N matrix A(by bisection
 *>                and inverse iteration)
+*>       SGESVDQ  compute SVD of an M-by-N matrix A(with a 
+*>                QR-Preconditioned )
 *> \endverbatim
 *
 *  Arguments:
@@ -56,22 +58,22 @@
 *  Authors:
 *  ========
 *
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
 *
-*> \date November 2015
+*> \date June 2016
 *
 *> \ingroup single_eig
 *
 *  =====================================================================
       SUBROUTINE SERRED( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK test routine (version 3.7.0) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2015
+*     June 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
@@ -100,7 +102,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           CHKXER, SGEES, SGEESX, SGEEV, SGEEVX, SGEJSV,
-     $                   SGESDD, SGESVD
+     $                   SGESDD, SGESVD, SGESVDX, SGESVDQ
 *     ..
 *     .. External Functions ..
       LOGICAL            SSLECT, LSAMEN
@@ -415,7 +417,7 @@
      $                 2, 2, A, 2, S, U, 1, VT, 2,
      $                 W, 1, IW, INFO)
          CALL CHKXER( 'SGEJSV', INFOT, NOUT, LERR, OK )
-         INFOT = 14
+         INFOT = 15
          CALL SGEJSV( 'G', 'U', 'V', 'R', 'N', 'N',
      $                 2, 2, A, 2, S, U, 2, VT, 1,
      $                 W, 1, IW, INFO)
@@ -432,51 +434,51 @@
 *
          SRNAMT = 'SGESVDX'
          INFOT = 1
-         CALL SGESVDX( 'X', 'N', 'A', 0, 0, A, 1, ZERO, ZERO, 
+         CALL SGESVDX( 'X', 'N', 'A', 0, 0, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 2
-         CALL SGESVDX( 'N', 'X', 'A', 0, 0, A, 1, ZERO, ZERO, 
+         CALL SGESVDX( 'N', 'X', 'A', 0, 0, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 3
-         CALL SGESVDX( 'N', 'N', 'X', 0, 0, A, 1, ZERO, ZERO, 
+         CALL SGESVDX( 'N', 'N', 'X', 0, 0, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 4
-         CALL SGESVDX( 'N', 'N', 'A', -1, 0, A, 1, ZERO, ZERO, 
+         CALL SGESVDX( 'N', 'N', 'A', -1, 0, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 5
-         CALL SGESVDX( 'N', 'N', 'A', 0, -1, A, 1, ZERO, ZERO, 
+         CALL SGESVDX( 'N', 'N', 'A', 0, -1, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 7
-         CALL SGESVDX( 'N', 'N', 'A', 2, 1, A, 1, ZERO, ZERO, 
+         CALL SGESVDX( 'N', 'N', 'A', 2, 1, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 8
-         CALL SGESVDX( 'N', 'N', 'V', 2, 1, A, 2, -ONE, ZERO, 
+         CALL SGESVDX( 'N', 'N', 'V', 2, 1, A, 2, -ONE, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 9
-         CALL SGESVDX( 'N', 'N', 'V', 2, 1, A, 2, ONE, ZERO, 
+         CALL SGESVDX( 'N', 'N', 'V', 2, 1, A, 2, ONE, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 10
-         CALL SGESVDX( 'N', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
+         CALL SGESVDX( 'N', 'N', 'I', 2, 2, A, 2, ZERO, ZERO,
      $                 0, 1, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 11
-         CALL SGESVDX( 'V', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
+         CALL SGESVDX( 'V', 'N', 'I', 2, 2, A, 2, ZERO, ZERO,
      $                 1, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 15
-         CALL SGESVDX( 'V', 'N', 'A', 2, 2, A, 2, ZERO, ZERO, 
+         CALL SGESVDX( 'V', 'N', 'A', 2, 2, A, 2, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
-         INFOT = 16
-         CALL SGESVDX( 'N', 'V', 'A', 2, 2, A, 2, ZERO, ZERO, 
+         INFOT = 17
+         CALL SGESVDX( 'N', 'V', 'A', 2, 2, A, 2, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, IW, INFO )
          CALL CHKXER( 'SGESVDX', INFOT, NOUT, LERR, OK )
          NT = 12
@@ -486,6 +488,61 @@
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
+*
+*        Test SGESVDQ
+*
+         SRNAMT = 'SGESVDQ'
+         INFOT = 1
+         CALL SGESVDQ( 'X', 'P', 'T', 'A', 'A', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 2
+         CALL SGESVDQ( 'A', 'X', 'T', 'A', 'A', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 3
+         CALL SGESVDQ( 'A', 'P', 'X', 'A', 'A', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 4
+         CALL SGESVDQ( 'A', 'P', 'T', 'X', 'A', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 5
+         CALL SGESVDQ( 'A', 'P', 'T', 'A', 'X', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 6
+         CALL SGESVDQ( 'A', 'P', 'T', 'A', 'A', -1, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 7
+         CALL SGESVDQ( 'A', 'P', 'T', 'A', 'A', 0, 1, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 9
+         CALL SGESVDQ( 'A', 'P', 'T', 'A', 'A', 1, 1, A, 0, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 12
+         CALL SGESVDQ( 'A', 'P', 'T', 'A', 'A', 1, 1, A, 1, S, U,
+     $                 -1, VT, 0, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 14
+         CALL SGESVDQ( 'A', 'P', 'T', 'A', 'A', 1, 1, A, 1, S, U,
+     $                 1, VT, -1, NS, IW, 1, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 17
+         CALL SGESVDQ( 'A', 'P', 'T', 'A', 'A', 1, 1, A, 1, S, U,
+     $                 1, VT, 1, NS, IW, -5, W, 1, W, 1, INFO )
+         CALL CHKXER( 'SGESVDQ', INFOT, NOUT, LERR, OK )
+         NT = 11
+         IF( OK ) THEN
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
+         ELSE
+            WRITE( NOUT, FMT = 9998 )
+         END IF
       END IF
 *
 *     Print a summary line.
