@@ -162,7 +162,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
+*> \date November 2017
 *
 *
 *> \ingroup complex_lin
@@ -172,10 +172,10 @@
      $                      THRESH, TSTERR, NMAX, A, AFAC, AINV, B,
      $                      X, XACT, WORK, RWORK, IWORK, NOUT )
 *
-*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK test routine (version 3.8.0) --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
+*     November 2017
 *
       IMPLICIT NONE
 *
@@ -218,18 +218,13 @@
       INTEGER      ISEED( 4 ), ISEEDY( 4 )
       REAL         RESULT( NTESTS )
 *     ..
-*     .. External Functions ..
-      REAL         DGET06, CLANHE
-      EXTERNAL     DGET06, CLANHE
-*     ..
 *     .. External Subroutines ..
-      EXTERNAL     ALAERH, ALAHD, ALASUM, XLAENV, CERRHE, CGET04,
-     $             ZHECON, CHERFS, CHET01_AA, CHETRF_AA, ZHETRI2,
-     $             CHETRS_AA, CLACPY, CLAIPD, CLARHS, CLATB4, 
-     $             CLATMS, CPOT02, ZPOT03, ZPOT05
+      EXTERNAL     ALAERH, ALAHD, ALASUM, XLAENV, CERRHE, CHET01_AA,
+     $             CHETRF_AA, CHETRS_AA, CLACPY, CLAIPD, CLARHS,
+     $             CLATB4, CLATMS, CPOT02
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC    REAL, IMAG, MAX, MIN
+      INTRINSIC    MAX, MIN
 *     ..
 *     .. Scalars in Common ..
       LOGICAL      LERR, OK
@@ -439,22 +434,22 @@
 *                 Adjust the expected value of INFO to account for
 *                 pivoting.
 *
-                  IF( IZERO.GT.0 ) THEN
-                     J = 1
-                     K = IZERO
-  100                CONTINUE
-                     IF( J.EQ.K ) THEN
-                        K = IWORK( J )
-                     ELSE IF( IWORK( J ).EQ.K ) THEN
-                        K = J
-                     END IF
-                     IF( J.LT.K ) THEN
-                        J = J + 1
-                        GO TO 100
-                     END IF
-                  ELSE
+c                  IF( IZERO.GT.0 ) THEN
+c                     J = 1
+c                     K = IZERO
+c  100                CONTINUE
+c                     IF( J.EQ.K ) THEN
+c                        K = IWORK( J )
+c                     ELSE IF( IWORK( J ).EQ.K ) THEN
+c                        K = J
+c                     END IF
+c                     IF( J.LT.K ) THEN
+c                        J = J + 1
+c                        GO TO 100
+c                     END IF
+c                  ELSE
                      K = 0
-                  END IF
+c                  END IF
 *
 *                 Check error code from CHETRF and handle error.
 *
@@ -517,30 +512,33 @@
 *                    Check error code from CHETRS and handle error.
 *
                      IF( INFO.NE.0 ) THEN
-                        CALL ALAERH( PATH, 'CHETRS_AA', INFO, 0,
-     $                                UPLO, N, N, -1, -1, NRHS, IMAT,
-     $                                NFAIL, NERRS, NOUT )
-                     END IF
-*
-                     CALL CLACPY( 'Full', N, NRHS, B, LDA, WORK, LDA )
-*
-*                    Compute the residual for the solution
-*
-                     CALL CPOT02( UPLO, N, NRHS, A, LDA, X, LDA, WORK,
-     $                            LDA, RWORK, RESULT( 2 ) )
-*
-*                    Print information about the tests that did not pass
-*                    the threshold.
-*
-                     DO 120 K = 2, 2
-                        IF( RESULT( K ).GE.THRESH ) THEN
-                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                        CALL ALAHD( NOUT, PATH )
-                           WRITE( NOUT, FMT = 9998 )UPLO, N, NRHS,
-     $                        IMAT, K, RESULT( K )
-                           NFAIL = NFAIL + 1
+                        IF( IZERO.EQ.0 ) THEN
+                           CALL ALAERH( PATH, 'CHETRS_AA', INFO, 0,
+     $                                   UPLO, N, N, -1, -1, NRHS, IMAT,
+     $                                   NFAIL, NERRS, NOUT )
                         END IF
-  120                CONTINUE
+                     ELSE
+                        CALL CLACPY( 'Full', N, NRHS, B, LDA, WORK, LDA
+     $                               )
+*
+*                       Compute the residual for the solution
+*
+                        CALL CPOT02( UPLO, N, NRHS, A, LDA, X, LDA,
+     $                               WORK, LDA, RWORK, RESULT( 2 ) )
+*
+*                       Print information about the tests that did not pass
+*                       the threshold.
+*
+                        DO 120 K = 2, 2
+                           IF( RESULT( K ).GE.THRESH ) THEN
+                              IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                           CALL ALAHD( NOUT, PATH )
+                              WRITE( NOUT, FMT = 9998 )UPLO, N, NRHS,
+     $                           IMAT, K, RESULT( K )
+                              NFAIL = NFAIL + 1
+                           END IF
+  120                   CONTINUE
+                     END IF
                      NRUN = NRUN + 1
 *
 *                 End do for each value of NRHS in NSVAL.
