@@ -1,88 +1,194 @@
-      SUBROUTINE SCHKPB( DOTYPE, NN, NVAL, NNB, NBVAL, NRHS, THRESH,
-     $                   TSTERR, NMAX, A, AFAC, AINV, B, X, XACT, WORK,
-     $                   RWORK, IWORK, NOUT )
+*> \brief \b SCHKPB
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SCHKPB( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
+*                          THRESH, TSTERR, NMAX, A, AFAC, AINV, B, X,
+*                          XACT, WORK, RWORK, IWORK, NOUT )
+*
+*       .. Scalar Arguments ..
+*       LOGICAL            TSTERR
+*       INTEGER            NMAX, NN, NNB, NNS, NOUT
+*       REAL               THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            DOTYPE( * )
+*       INTEGER            IWORK( * ), NBVAL( * ), NSVAL( * ), NVAL( * )
+*       REAL               A( * ), AFAC( * ), AINV( * ), B( * ),
+*      $                   RWORK( * ), WORK( * ), X( * ), XACT( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SCHKPB tests SPBTRF, -TRS, -RFS, and -CON.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          The matrix types to be used for testing.  Matrices of type j
+*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER
+*>          The number of values of N contained in the vector NVAL.
+*> \endverbatim
+*>
+*> \param[in] NVAL
+*> \verbatim
+*>          NVAL is INTEGER array, dimension (NN)
+*>          The values of the matrix dimension N.
+*> \endverbatim
+*>
+*> \param[in] NNB
+*> \verbatim
+*>          NNB is INTEGER
+*>          The number of values of NB contained in the vector NBVAL.
+*> \endverbatim
+*>
+*> \param[in] NBVAL
+*> \verbatim
+*>          NBVAL is INTEGER array, dimension (NBVAL)
+*>          The values of the blocksize NB.
+*> \endverbatim
+*>
+*> \param[in] NNS
+*> \verbatim
+*>          NNS is INTEGER
+*>          The number of values of NRHS contained in the vector NSVAL.
+*> \endverbatim
+*>
+*> \param[in] NSVAL
+*> \verbatim
+*>          NSVAL is INTEGER array, dimension (NNS)
+*>          The values of the number of right hand sides NRHS.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is REAL
+*>          The threshold value for the test ratios.  A result is
+*>          included in the output file if RESULT >= THRESH.  To have
+*>          every test ratio printed, use THRESH = 0.
+*> \endverbatim
+*>
+*> \param[in] TSTERR
+*> \verbatim
+*>          TSTERR is LOGICAL
+*>          Flag that indicates whether error exits are to be tested.
+*> \endverbatim
+*>
+*> \param[in] NMAX
+*> \verbatim
+*>          NMAX is INTEGER
+*>          The maximum value permitted for N, used in dimensioning the
+*>          work arrays.
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is REAL array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] AFAC
+*> \verbatim
+*>          AFAC is REAL array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] AINV
+*> \verbatim
+*>          AINV is REAL array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is REAL array, dimension (NMAX*NSMAX)
+*>          where NSMAX is the largest entry in NSVAL.
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is REAL array, dimension (NMAX*NSMAX)
+*> \endverbatim
+*>
+*> \param[out] XACT
+*> \verbatim
+*>          XACT is REAL array, dimension (NMAX*NSMAX)
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is REAL array, dimension
+*>                      (NMAX*max(3,NSMAX))
+*> \endverbatim
+*>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is REAL array, dimension
+*>                      (max(NMAX,2*NSMAX))
+*> \endverbatim
+*>
+*> \param[out] IWORK
+*> \verbatim
+*>          IWORK is INTEGER array, dimension (NMAX)
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup single_lin
+*
+*  =====================================================================
+      SUBROUTINE SCHKPB( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
+     $                   THRESH, TSTERR, NMAX, A, AFAC, AINV, B, X,
+     $                   XACT, WORK, RWORK, IWORK, NOUT )
+*
+*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
-      INTEGER            NMAX, NN, NNB, NOUT, NRHS
+      INTEGER            NMAX, NN, NNB, NNS, NOUT
       REAL               THRESH
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            IWORK( * ), NBVAL( * ), NVAL( * )
+      INTEGER            IWORK( * ), NBVAL( * ), NSVAL( * ), NVAL( * )
       REAL               A( * ), AFAC( * ), AINV( * ), B( * ),
      $                   RWORK( * ), WORK( * ), X( * ), XACT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SCHKPB tests SPBTRF, -TRS, -RFS, and -CON.
-*
-*  Arguments
-*  =========
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          The matrix types to be used for testing.  Matrices of type j
-*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*
-*  NN      (input) INTEGER
-*          The number of values of N contained in the vector NVAL.
-*
-*  NVAL    (input) INTEGER array, dimension (NN)
-*          The values of the matrix dimension N.
-*
-*  NNB     (input) INTEGER
-*          The number of values of NB contained in the vector NBVAL.
-*
-*  NBVAL   (input) INTEGER array, dimension (NBVAL)
-*          The values of the blocksize NB.
-*
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
-*
-*  THRESH  (input) REAL
-*          The threshold value for the test ratios.  A result is
-*          included in the output file if RESULT >= THRESH.  To have
-*          every test ratio printed, use THRESH = 0.
-*
-*  TSTERR  (input) LOGICAL
-*          Flag that indicates whether error exits are to be tested.
-*
-*  NMAX    (input) INTEGER
-*          The maximum value permitted for N, used in dimensioning the
-*          work arrays.
-*
-*  A       (workspace) REAL array, dimension (NMAX*NMAX)
-*
-*  AFAC    (workspace) REAL array, dimension (NMAX*NMAX)
-*
-*  AINV    (workspace) REAL array, dimension (NMAX*NMAX)
-*
-*  B       (workspace) REAL array, dimension (NMAX*NRHS)
-*
-*  X       (workspace) REAL array, dimension (NMAX*NRHS)
-*
-*  XACT    (workspace) REAL array, dimension (NMAX*NRHS)
-*
-*  WORK    (workspace) REAL array, dimension
-*                      (NMAX*max(3,NRHS))
-*
-*  RWORK   (workspace) REAL array, dimension
-*                      (max(NMAX,2*NRHS))
-*
-*  IWORK   (workspace) INTEGER array, dimension (NMAX)
-*
-*  NOUT    (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -98,9 +204,9 @@
       CHARACTER          DIST, PACKIT, TYPE, UPLO, XTYPE
       CHARACTER*3        PATH
       INTEGER            I, I1, I2, IKD, IMAT, IN, INB, INFO, IOFF,
-     $                   IUPLO, IW, IZERO, K, KD, KL, KOFF, KU, LDA,
-     $                   LDAB, MODE, N, NB, NERRS, NFAIL, NIMAT, NKD,
-     $                   NRUN, NT
+     $                   IRHS, IUPLO, IW, IZERO, K, KD, KL, KOFF, KU,
+     $                   LDA, LDAB, MODE, N, NB, NERRS, NFAIL, NIMAT,
+     $                   NKD, NRHS, NRUN
       REAL               AINVNM, ANORM, CNDNUM, RCOND, RCONDC
 *     ..
 *     .. Local Arrays ..
@@ -113,7 +219,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAERH, ALAHD, ALASUM, SCOPY, SERRPO, SGET04,
-     $                   SLACPY, SLARHS, SLATB4, SLATMS, SLASET, SPBCON,
+     $                   SLACPY, SLARHS, SLASET, SLATB4, SLATMS, SPBCON,
      $                   SPBRFS, SPBT01, SPBT02, SPBT05, SPBTRF, SPBTRS,
      $                   SSWAP, XLAENV
 *     ..
@@ -122,7 +228,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -136,7 +242,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'S'
+      PATH( 1: 1 ) = 'Single precision'
       PATH( 2: 3 ) = 'PB'
       NRUN = 0
       NFAIL = 0
@@ -328,12 +434,22 @@
      $                            LDAB )
                      CALL SPBT01( UPLO, N, KD, A, LDAB, AINV, LDAB,
      $                            RWORK, RESULT( 1 ) )
-                     NT = 1
+*
+*                    Print the test ratio if it is .GE. THRESH.
+*
+                     IF( RESULT( 1 ).GE.THRESH ) THEN
+                        IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                     CALL ALAHD( NOUT, PATH )
+                        WRITE( NOUT, FMT = 9999 )UPLO, N, KD, NB, IMAT,
+     $                     1, RESULT( 1 )
+                        NFAIL = NFAIL + 1
+                     END IF
+                     NRUN = NRUN + 1
 *
 *                    Only do other tests if this is the first blocksize.
 *
                      IF( INB.GT.1 )
-     $                  GO TO 30
+     $                  GO TO 50
 *
 *                    Form the inverse of A so we can get a good estimate
 *                    of RCONDC = 1/(norm(A) * norm(inv(A))).
@@ -352,58 +468,77 @@
                      ELSE
                         RCONDC = ( ONE / ANORM ) / AINVNM
                      END IF
+*
+                     DO 40 IRHS = 1, NNS
+                        NRHS = NSVAL( IRHS )
 *
 *+    TEST 2
 *                    Solve and compute residual for A * X = B.
 *
-                     SRNAMT = 'SLARHS'
-                     CALL SLARHS( PATH, XTYPE, UPLO, ' ', N, N, KD, KD,
-     $                            NRHS, A, LDAB, XACT, LDA, B, LDA,
-     $                            ISEED, INFO )
-                     XTYPE = 'C'
-                     CALL SLACPY( 'Full', N, NRHS, B, LDA, X, LDA )
+                        SRNAMT = 'SLARHS'
+                        CALL SLARHS( PATH, XTYPE, UPLO, ' ', N, N, KD,
+     $                               KD, NRHS, A, LDAB, XACT, LDA, B,
+     $                               LDA, ISEED, INFO )
+                        CALL SLACPY( 'Full', N, NRHS, B, LDA, X, LDA )
 *
-                     SRNAMT = 'SPBTRS'
-                     CALL SPBTRS( UPLO, N, KD, NRHS, AFAC, LDAB, X, LDA,
-     $                            INFO )
+                        SRNAMT = 'SPBTRS'
+                        CALL SPBTRS( UPLO, N, KD, NRHS, AFAC, LDAB, X,
+     $                               LDA, INFO )
 *
 *                    Check error code from SPBTRS.
 *
-                     IF( INFO.NE.0 )
-     $                  CALL ALAERH( PATH, 'SPBTRS', INFO, 0, UPLO, N,
-     $                               N, KD, KD, NRHS, IMAT, NFAIL,
-     $                               NERRS, NOUT )
+                        IF( INFO.NE.0 )
+     $                     CALL ALAERH( PATH, 'SPBTRS', INFO, 0, UPLO,
+     $                                  N, N, KD, KD, NRHS, IMAT, NFAIL,
+     $                                  NERRS, NOUT )
 *
-                     CALL SLACPY( 'Full', N, NRHS, B, LDA, WORK, LDA )
-                     CALL SPBT02( UPLO, N, KD, NRHS, A, LDAB, X, LDA,
-     $                            WORK, LDA, RWORK, RESULT( 2 ) )
+                        CALL SLACPY( 'Full', N, NRHS, B, LDA, WORK,
+     $                               LDA )
+                        CALL SPBT02( UPLO, N, KD, NRHS, A, LDAB, X, LDA,
+     $                               WORK, LDA, RWORK, RESULT( 2 ) )
 *
 *+    TEST 3
 *                    Check solution from generated exact solution.
 *
-                     CALL SGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
-     $                            RESULT( 3 ) )
+                        CALL SGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
+     $                               RESULT( 3 ) )
 *
 *+    TESTS 4, 5, and 6
 *                    Use iterative refinement to improve the solution.
 *
-                     SRNAMT = 'SPBRFS'
-                     CALL SPBRFS( UPLO, N, KD, NRHS, A, LDAB, AFAC,
-     $                            LDAB, B, LDA, X, LDA, RWORK,
-     $                            RWORK( NRHS+1 ), WORK, IWORK, INFO )
+                        SRNAMT = 'SPBRFS'
+                        CALL SPBRFS( UPLO, N, KD, NRHS, A, LDAB, AFAC,
+     $                               LDAB, B, LDA, X, LDA, RWORK,
+     $                               RWORK( NRHS+1 ), WORK, IWORK,
+     $                               INFO )
 *
 *                    Check error code from SPBRFS.
 *
-                     IF( INFO.NE.0 )
-     $                  CALL ALAERH( PATH, 'SPBRFS', INFO, 0, UPLO, N,
-     $                               N, KD, KD, NRHS, IMAT, NFAIL,
-     $                               NERRS, NOUT )
+                        IF( INFO.NE.0 )
+     $                     CALL ALAERH( PATH, 'SPBRFS', INFO, 0, UPLO,
+     $                                  N, N, KD, KD, NRHS, IMAT, NFAIL,
+     $                                  NERRS, NOUT )
 *
-                     CALL SGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
-     $                            RESULT( 4 ) )
-                     CALL SPBT05( UPLO, N, KD, NRHS, A, LDAB, B, LDA, X,
-     $                            LDA, XACT, LDA, RWORK,
-     $                            RWORK( NRHS+1 ), RESULT( 5 ) )
+                        CALL SGET04( N, NRHS, X, LDA, XACT, LDA, RCONDC,
+     $                               RESULT( 4 ) )
+                        CALL SPBT05( UPLO, N, KD, NRHS, A, LDAB, B, LDA,
+     $                               X, LDA, XACT, LDA, RWORK,
+     $                               RWORK( NRHS+1 ), RESULT( 5 ) )
+*
+*                       Print information about the tests that did not
+*                       pass the threshold.
+*
+                        DO 30 K = 2, 6
+                           IF( RESULT( K ).GE.THRESH ) THEN
+                              IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                           CALL ALAHD( NOUT, PATH )
+                              WRITE( NOUT, FMT = 9998 )UPLO, N, KD,
+     $                           NRHS, IMAT, K, RESULT( K )
+                              NFAIL = NFAIL + 1
+                           END IF
+   30                   CONTINUE
+                        NRUN = NRUN + 5
+   40                CONTINUE
 *
 *+    TEST 7
 *                    Get an estimate of RCOND = 1/CNDNUM.
@@ -420,24 +555,18 @@
      $                               NOUT )
 *
                      RESULT( 7 ) = SGET06( RCOND, RCONDC )
-                     NT = 7
 *
-*                    Print information about the tests that did not pass
-*                    the threshold.
+*                    Print the test ratio if it is .GE. THRESH.
 *
-   30                CONTINUE
-                     DO 40 K = 1, NT
-                        IF( RESULT( K ).GE.THRESH ) THEN
-                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                        CALL ALAHD( NOUT, PATH )
-                           WRITE( NOUT, FMT = 9999 )UPLO, N, KD, NB,
-     $                        IMAT, K, RESULT( K )
-                           NFAIL = NFAIL + 1
-                        END IF
-   40                CONTINUE
-                     NRUN = NRUN + NT
+                     IF( RESULT( 7 ).GE.THRESH ) THEN
+                        IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                     CALL ALAHD( NOUT, PATH )
+                        WRITE( NOUT, FMT = 9997 )UPLO, N, KD, IMAT, 7,
+     $                     RESULT( 7 )
+                        NFAIL = NFAIL + 1
+                     END IF
+                     NRUN = NRUN + 1
    50             CONTINUE
-*
    60          CONTINUE
    70       CONTINUE
    80    CONTINUE
@@ -449,6 +578,10 @@
 *
  9999 FORMAT( ' UPLO=''', A1, ''', N=', I5, ', KD=', I5, ', NB=', I4,
      $      ', type ', I2, ', test ', I2, ', ratio= ', G12.5 )
+ 9998 FORMAT( ' UPLO=''', A1, ''', N=', I5, ', KD=', I5, ', NRHS=', I3,
+     $      ', type ', I2, ', test(', I2, ') = ', G12.5 )
+ 9997 FORMAT( ' UPLO=''', A1, ''', N=', I5, ', KD=', I5, ',', 10X,
+     $      ' type ', I2, ', test(', I2, ') = ', G12.5 )
       RETURN
 *
 *     End of SCHKPB
