@@ -1,29 +1,69 @@
+*> \brief \b SERRTZ
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SERRTZ( PATH, NUNIT )
+*
+*       .. Scalar Arguments ..
+*       CHARACTER*3        PATH
+*       INTEGER            NUNIT
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SERRTZ tests the error exits for STZRZF.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] PATH
+*> \verbatim
+*>          PATH is CHARACTER*3
+*>          The LAPACK path name for the routines to be tested.
+*> \endverbatim
+*>
+*> \param[in] NUNIT
+*> \verbatim
+*>          NUNIT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup single_lin
+*
+*  =====================================================================
       SUBROUTINE SERRTZ( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
       INTEGER            NUNIT
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SERRTZ tests the error exits for STZRQF and STZRZF.
-*
-*  Arguments
-*  =========
-*
-*  PATH    (input) CHARACTER*3
-*          The LAPACK path name for the routines to be tested.
-*
-*  NUNIT   (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -42,11 +82,11 @@
       EXTERNAL           LSAMEN
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALAESM, CHKXER, STZRQF, STZRZF
+      EXTERNAL           ALAESM, CHKXER, STZRZF
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NOUT
 *     ..
 *     .. Common blocks ..
@@ -70,19 +110,6 @@
 *
 *        Test error exits for the trapezoidal routines.
 *
-*        STZRQF
-*
-         SRNAMT = 'STZRQF'
-         INFOT = 1
-         CALL STZRQF( -1, 0, A, 1, TAU, INFO )
-         CALL CHKXER( 'STZRQF', INFOT, NOUT, LERR, OK )
-         INFOT = 2
-         CALL STZRQF( 1, 0, A, 1, TAU, INFO )
-         CALL CHKXER( 'STZRQF', INFOT, NOUT, LERR, OK )
-         INFOT = 4
-         CALL STZRQF( 2, 2, A, 1, TAU, INFO )
-         CALL CHKXER( 'STZRQF', INFOT, NOUT, LERR, OK )
-*
 *        STZRZF
 *
          SRNAMT = 'STZRZF'
@@ -96,7 +123,10 @@
          CALL STZRZF( 2, 2, A, 1, TAU, W, 1, INFO )
          CALL CHKXER( 'STZRZF', INFOT, NOUT, LERR, OK )
          INFOT = 7
-         CALL STZRZF( 2, 2, A, 2, TAU, W, 1, INFO )
+         CALL STZRZF( 2, 2, A, 2, TAU, W, 0, INFO )
+         CALL CHKXER( 'STZRZF', INFOT, NOUT, LERR, OK )
+         INFOT = 7
+         CALL STZRZF( 2, 3, A, 2, TAU, W, 1, INFO )
          CALL CHKXER( 'STZRZF', INFOT, NOUT, LERR, OK )
       END IF
 *
