@@ -1,11 +1,168 @@
+*> \brief \b ZDRVPO
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE ZDRVPO( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
+*                          A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
+*                          RWORK, NOUT )
+*
+*       .. Scalar Arguments ..
+*       LOGICAL            TSTERR
+*       INTEGER            NMAX, NN, NOUT, NRHS
+*       DOUBLE PRECISION   THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            DOTYPE( * )
+*       INTEGER            NVAL( * )
+*       DOUBLE PRECISION   RWORK( * ), S( * )
+*       COMPLEX*16         A( * ), AFAC( * ), ASAV( * ), B( * ),
+*      $                   BSAV( * ), WORK( * ), X( * ), XACT( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> ZDRVPO tests the driver routines ZPOSV and -SVX.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          The matrix types to be used for testing.  Matrices of type j
+*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER
+*>          The number of values of N contained in the vector NVAL.
+*> \endverbatim
+*>
+*> \param[in] NVAL
+*> \verbatim
+*>          NVAL is INTEGER array, dimension (NN)
+*>          The values of the matrix dimension N.
+*> \endverbatim
+*>
+*> \param[in] NRHS
+*> \verbatim
+*>          NRHS is INTEGER
+*>          The number of right hand side vectors to be generated for
+*>          each linear system.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is DOUBLE PRECISION
+*>          The threshold value for the test ratios.  A result is
+*>          included in the output file if RESULT >= THRESH.  To have
+*>          every test ratio printed, use THRESH = 0.
+*> \endverbatim
+*>
+*> \param[in] TSTERR
+*> \verbatim
+*>          TSTERR is LOGICAL
+*>          Flag that indicates whether error exits are to be tested.
+*> \endverbatim
+*>
+*> \param[in] NMAX
+*> \verbatim
+*>          NMAX is INTEGER
+*>          The maximum value permitted for N, used in dimensioning the
+*>          work arrays.
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] AFAC
+*> \verbatim
+*>          AFAC is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] ASAV
+*> \verbatim
+*>          ASAV is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is COMPLEX*16 array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] BSAV
+*> \verbatim
+*>          BSAV is COMPLEX*16 array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is COMPLEX*16 array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] XACT
+*> \verbatim
+*>          XACT is COMPLEX*16 array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] S
+*> \verbatim
+*>          S is DOUBLE PRECISION array, dimension (NMAX)
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is COMPLEX*16 array, dimension
+*>                      (NMAX*max(3,NRHS))
+*> \endverbatim
+*>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is DOUBLE PRECISION array, dimension (NMAX+2*NRHS)
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \date December 2016
+*
+*> \ingroup complex16_lin
+*
+*  =====================================================================
       SUBROUTINE ZDRVPO( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
      $                   A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
      $                   RWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     December 2016
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -20,65 +177,6 @@
      $                   BSAV( * ), WORK( * ), X( * ), XACT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  ZDRVPO tests the driver routines ZPOSV and -SVX.
-*
-*  Arguments
-*  =========
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          The matrix types to be used for testing.  Matrices of type j
-*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*
-*  NN      (input) INTEGER
-*          The number of values of N contained in the vector NVAL.
-*
-*  NVAL    (input) INTEGER array, dimension (NN)
-*          The values of the matrix dimension N.
-*
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
-*
-*  THRESH  (input) DOUBLE PRECISION
-*          The threshold value for the test ratios.  A result is
-*          included in the output file if RESULT >= THRESH.  To have
-*          every test ratio printed, use THRESH = 0.
-*
-*  TSTERR  (input) LOGICAL
-*          Flag that indicates whether error exits are to be tested.
-*
-*  NMAX    (input) INTEGER
-*          The maximum value permitted for N, used in dimensioning the
-*          work arrays.
-*
-*  A       (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  AFAC    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  ASAV    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  BSAV    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  S       (workspace) DOUBLE PRECISION array, dimension (NMAX)
-*
-*  WORK    (workspace) COMPLEX*16 array, dimension
-*                      (NMAX*max(3,NRHS))
-*
-*  RWORK   (workspace) DOUBLE PRECISION array, dimension (NMAX+2*NRHS)
-*
-*  NOUT    (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -117,7 +215,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -137,7 +235,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'Z'
+      PATH( 1: 1 ) = 'Zomplex precision'
       PATH( 2: 3 ) = 'PO'
       NRUN = 0
       NFAIL = 0
@@ -161,7 +259,7 @@
 *
 *     Do for each value of N in NVAL
 *
-      DO 140 IN = 1, NN
+      DO 130 IN = 1, NN
          N = NVAL( IN )
          LDA = MAX( N, 1 )
          XTYPE = 'N'
@@ -169,22 +267,22 @@
          IF( N.LE.0 )
      $      NIMAT = 1
 *
-         DO 130 IMAT = 1, NIMAT
+         DO 120 IMAT = 1, NIMAT
 *
 *           Do the tests only if DOTYPE( IMAT ) is true.
 *
             IF( .NOT.DOTYPE( IMAT ) )
-     $         GO TO 130
+     $         GO TO 120
 *
 *           Skip types 3, 4, or 5 if the matrix size is too small.
 *
             ZEROT = IMAT.GE.3 .AND. IMAT.LE.5
             IF( ZEROT .AND. N.LT.IMAT-2 )
-     $         GO TO 130
+     $         GO TO 120
 *
 *           Do first for UPLO = 'U', then for UPLO = 'L'
 *
-            DO 120 IUPLO = 1, 2
+            DO 110 IUPLO = 1, 2
                UPLO = UPLOS( IUPLO )
 *
 *              Set up parameters with ZLATB4 and generate a test matrix
@@ -203,7 +301,7 @@
                IF( INFO.NE.0 ) THEN
                   CALL ALAERH( PATH, 'ZLATMS', INFO, 0, UPLO, N, N, -1,
      $                         -1, -1, IMAT, NFAIL, NERRS, NOUT )
-                  GO TO 120
+                  GO TO 110
                END IF
 *
 *              For types 3-5, zero one row and column of the matrix to
@@ -253,7 +351,7 @@
 *
                CALL ZLACPY( UPLO, N, N, A, LDA, ASAV, LDA )
 *
-               DO 110 IEQUED = 1, 2
+               DO 100 IEQUED = 1, 2
                   EQUED = EQUEDS( IEQUED )
                   IF( IEQUED.EQ.1 ) THEN
                      NFACT = 3
@@ -261,7 +359,7 @@
                      NFACT = 1
                   END IF
 *
-                  DO 100 IFACT = 1, NFACT
+                  DO 90 IFACT = 1, NFACT
                      FACT = FACTS( IFACT )
                      PREFAC = LSAME( FACT, 'F' )
                      NOFACT = LSAME( FACT, 'N' )
@@ -269,7 +367,7 @@
 *
                      IF( ZEROT ) THEN
                         IF( PREFAC )
-     $                     GO TO 100
+     $                     GO TO 90
                         RCONDC = ZERO
 *
                      ELSE IF( .NOT.LSAME( FACT, 'N' ) ) THEN
@@ -326,7 +424,6 @@
                            RCONDC = ( ONE / ANORM ) / AINVNM
                         END IF
                      END IF
-   60                CONTINUE
 *
 *                    Restore the matrix A.
 *
@@ -361,9 +458,9 @@
                            CALL ALAERH( PATH, 'ZPOSV ', INFO, IZERO,
      $                                  UPLO, N, N, -1, -1, NRHS, IMAT,
      $                                  NFAIL, NERRS, NOUT )
-                           GO TO 80
+                           GO TO 70
                         ELSE IF( INFO.NE.0 ) THEN
-                           GO TO 80
+                           GO TO 70
                         END IF
 *
 *                       Reconstruct matrix from factors and compute
@@ -388,7 +485,7 @@
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 70 K = 1, NT
+                        DO 60 K = 1, NT
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -396,9 +493,9 @@
      $                           N, IMAT, K, RESULT( K )
                               NFAIL = NFAIL + 1
                            END IF
-   70                   CONTINUE
+   60                   CONTINUE
                         NRUN = NRUN + NT
-   80                   CONTINUE
+   70                   CONTINUE
                      END IF
 *
 *                    --- Test ZPOSVX ---
@@ -432,7 +529,7 @@
                         CALL ALAERH( PATH, 'ZPOSVX', INFO, IZERO,
      $                               FACT // UPLO, N, N, -1, -1, NRHS,
      $                               IMAT, NFAIL, NERRS, NOUT )
-                        GO TO 100
+                        GO TO 90
                      END IF
 *
                      IF( INFO.EQ.0 ) THEN
@@ -485,7 +582,7 @@
 *                    Print information about the tests that did not pass
 *                    the threshold.
 *
-                     DO 90 K = K1, 6
+                     DO 80 K = K1, 6
                         IF( RESULT( K ).GE.THRESH ) THEN
                            IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                        CALL ALADHD( NOUT, PATH )
@@ -498,23 +595,23 @@
                            END IF
                            NFAIL = NFAIL + 1
                         END IF
-   90                CONTINUE
+   80                CONTINUE
                      NRUN = NRUN + 7 - K1
-  100             CONTINUE
-  110          CONTINUE
-  120       CONTINUE
-  130    CONTINUE
-  140 CONTINUE
+   90             CONTINUE
+  100          CONTINUE
+  110       CONTINUE
+  120    CONTINUE
+  130 CONTINUE
 *
 *     Print a summary of the results.
 *
       CALL ALASVM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
- 9999 FORMAT( 1X, A6, ', UPLO=''', A1, ''', N =', I5, ', type ', I1,
+ 9999 FORMAT( 1X, A, ', UPLO=''', A1, ''', N =', I5, ', type ', I1,
      $      ', test(', I1, ')=', G12.5 )
- 9998 FORMAT( 1X, A6, ', FACT=''', A1, ''', UPLO=''', A1, ''', N=', I5,
+ 9998 FORMAT( 1X, A, ', FACT=''', A1, ''', UPLO=''', A1, ''', N=', I5,
      $      ', type ', I1, ', test(', I1, ')=', G12.5 )
- 9997 FORMAT( 1X, A6, ', FACT=''', A1, ''', UPLO=''', A1, ''', N=', I5,
+ 9997 FORMAT( 1X, A, ', FACT=''', A1, ''', UPLO=''', A1, ''', N=', I5,
      $      ', EQUED=''', A1, ''', type ', I1, ', test(', I1, ') =',
      $      G12.5 )
       RETURN
